package pay.platform.api.system.controller;

import com.mybatisflex.core.paginate.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pay.platform.api.system.servcie.PayOrderService;
import pay.platform.domain.PayOrder;

import java.io.Serializable;
import java.util.List;

/**
 * 订单 控制层。
 *
 * @author mybatis-flex-helper automatic generation
 * @since 1.0
 */
@RestController
@RequestMapping("/sys/pay/order")
@Tag(name = "订单控制层")
public class PayOrderController {

    @Autowired
    private PayOrderService PayOrderService;

    /**
     * 添加 订单
     *
     * @param PayOrder 订单
     * @return {@code true} 添加成功，{@code false} 添加失败
     */
    @PostMapping("/save")
    @Operation(summary = "添加订单")
    public boolean save(@RequestBody PayOrder PayOrder) {
        return PayOrderService.save(PayOrder);
    }


    /**
     * 根据主键删除订单
     *
     * @param id 主键
     * @return {@code true} 删除成功，{@code false} 删除失败
     */
    @DeleteMapping("/remove/{id}")
    @Operation(summary = "根据主键删除订单")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public boolean remove(@PathVariable Serializable id) {
        return PayOrderService.removeById(id);
    }


    /**
     * 根据主键更新订单
     *
     * @param PayOrder 订单
     * @return {@code true} 更新成功，{@code false} 更新失败
     */
    @PutMapping("/update")
    @Operation(summary = "根据主键更新订单")
    public boolean update(@RequestBody PayOrder PayOrder) {
        return PayOrderService.updateById(PayOrder);
    }


    /**
     * 查询所有订单
     *
     * @return 所有数据
     */
    @GetMapping("/list")
    @Operation(summary = "查询所有订单")
    public List<PayOrder> list() {
        return PayOrderService.list();
    }


    /**
     * 根据订单主键获取详细信息。
     *
     * @param id PayOrder主键
     * @return 订单详情
     */
    @GetMapping("/getInfo/{id}")
    @Operation(summary = "根据订单主键获取详细信息")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public PayOrder getInfo(@PathVariable Serializable id) {
        return PayOrderService.getById(id);
    }


    /**
     * 分页查询订单
     *
     * @param page 分页对象
     * @return 分页对象
     */
    @GetMapping("/page")
    @Operation(summary = "分页查询订单")
    @Parameters(value = {
            @Parameter(name = "pageNumber", description = "页码", required = true),
            @Parameter(name = "pageSize", description = "每页大小", required = true)
    })
    public Page<PayOrder> page(Page<PayOrder> page) {
        return PayOrderService.page(page);
    }
}