package pay.platform.api.system.controller;

import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pay.platform.api.system.servcie.PayMerchantService;
import pay.platform.core.security.util.SecurityUtil;
import pay.platform.domain.PayMerchant;
import pay.platform.domain.table.PayMerchantTableDef;

import java.io.Serializable;
import java.util.List;

/**
 * 商户 控制层。
 *
 * @author mybatis-flex-helper automatic generation
 * @since 1.0
 */
@RestController
@RequestMapping("/agent/pay/merchant")
@Tag(name = "商户控制层")
public class PayMerchantController {

    @Autowired
    private PayMerchantService PayMerchantService;

    /**
     * 添加 商户
     *
     * @param PayMerchant 商户
     * @return {@code true} 添加成功，{@code false} 添加失败
     */
    @PostMapping("/save")
    @Operation(summary = "添加商户")

    public boolean save(@RequestBody PayMerchant PayMerchant) {

        return PayMerchantService.saveMerchant(PayMerchant);
    }


    /**
     * 根据主键删除商户
     *
     * @param id 主键
     * @return {@code true} 删除成功，{@code false} 删除失败
     */
    @DeleteMapping("/remove/{id}")
    @Operation(summary = "根据主键删除商户")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public boolean remove(@PathVariable Serializable id) {
        return PayMerchantService.removeById(id);
    }


    /**
     * 根据主键更新商户
     *
     * @param PayMerchant 商户
     * @return {@code true} 更新成功，{@code false} 更新失败
     */
    @PutMapping("/update")
    @Operation(summary = "根据主键更新商户")
    public boolean update(@RequestBody PayMerchant PayMerchant) {
        return PayMerchantService.updateById(PayMerchant);
    }


    /**
     * 查询所有商户
     *
     * @return 所有数据
     */
    @GetMapping("/list")
    @Operation(summary = "查询所有商户")
    public List<PayMerchant> list() {
        QueryWrapper queryWrapper = new QueryWrapper().eq(String.valueOf(PayMerchantTableDef.PAY_MERCHANT.AGENT_ID), SecurityUtil.getCurrentUser().getUserid());
        return PayMerchantService.list(queryWrapper);
    }


    /**
     * 根据商户主键获取详细信息。
     *
     * @param id PayMerchant主键
     * @return 商户详情
     */
    @GetMapping("/getInfo/{id}")
    @Operation(summary = "根据商户主键获取详细信息")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public PayMerchant getInfo(@PathVariable Serializable id) {
        return PayMerchantService.getById(id);
    }


    /**
     * 分页查询商户
     *
     * @param page 分页对象
     * @return 分页对象
     */
    @GetMapping("/page")
    @Operation(summary = "分页查询商户")
    @Parameters(value = {
            @Parameter(name = "pageNumber", description = "页码", required = true),
            @Parameter(name = "pageSize", description = "每页大小", required = true)
    })
    public Page<PayMerchant> page(Page<PayMerchant> page) {
        QueryWrapper queryWrapper = new QueryWrapper().eq(String.valueOf(PayMerchantTableDef.PAY_MERCHANT.AGENT_ID), SecurityUtil.getCurrentUser().getUserid());
        return PayMerchantService.page(page, queryWrapper);
    }
}