package pay.platform.core.config;

import jakarta.annotation.PreDestroy;
import lombok.extern.slf4j.Slf4j;
import org.noear.folkmq.FolkMQ;
import org.noear.folkmq.client.MqClient;
import org.noear.folkmq.client.MqConsumeHandler;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import pay.platform.core.util.SpringContextUtil;

import java.io.IOException;
import java.util.Map;

/**
 * MqClient 配置
 */
@Slf4j
@Configuration
public class MQConfig {

    @Value("${IP:43.155.3.249}")
    private String ip;

    @Bean
    public MqClient mqClient(Map<String, MqConsumeHandler> subscriptionMap) throws IOException {
        String name = "admin";
        String url = STR."folkmq://\{ip}:18602";
        //创建客户端，并连接
        log.info("初始化MQ客户端, 信息：name:{} url: {}", name, url);
        MqClient client = FolkMQ.createClient(url).nameAs(name).connect();
        //订阅
        for (Map.Entry<String, MqConsumeHandler> subscription : subscriptionMap.entrySet()) {
            client.subscribe(subscription.getKey(), subscription.getValue());
        }
        return client;
    }

    @PreDestroy
    public void destroy() throws IOException {
        MqClient mqClient = SpringContextUtil.getBean(MqClient.class);
        mqClient.disconnect();
    }
}
